/*
 * Copyright (c) 2013 J. Lewis Muir <jlmuir@imca-cat.org>
 *
 * Permission to use, copy, modify, and distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

package org.imca_cat.procrun;

import java.io.InputStream;
import java.nio.ByteBuffer;

/**
 * An abstract class for consumers that read data from an {@link InputStream}
 * into a buffer.
 */
public abstract class BufferInputStreamConsumer extends AbstractInputStreamConsumer {
  /** The buffer into which data is read from the stream. */
  protected byte[] buffer;
  /** The current position within the buffer. */
  protected int bufferPosition;

  /**
   * Creates an instance with the specified stream and buffer size.
   *
   * @param stream stream from which to read
   * @param bufferSize size of the buffer into which data read from the input
   *          stream should be placed
   *
   * @since 2.0
   */
  public BufferInputStreamConsumer(InputStream stream, int bufferSize) {
    super(stream);
    buffer = new byte[bufferSize];
    bufferPosition = 0;
  }

  @Override
  protected ByteBuffer data() {
    return ByteBuffer.wrap(buffer, 0, bufferPosition);
  }
}